div#edit-bar,dl.portalMessage{display:none}body.template-member-registration div#edit-bar,body.template-usergroup-userprefs div#edit-bar,body.template-usergroup-groupprefs div#edit-bar,body.template-usergroup-controlpanel div#edit-bar{display:block}body{border-top:42px solid #1b1b1b}body.forceColors,body.mceContentBody{border-top:0}#portal-header .plone-tile{float:left}